@@ -267,7 +267,7 @@ class CameraFrameWorkerSettings(TypedDict):
 
 class Camera(TypedDict):
     _id: str
-    nativeId: NotRequired[str]
+    nativeId: NotRequired[Optional[str]]
     pluginId: str
     name: str
     disabled: bool
@@ -315,17 +315,6 @@ CameraPublicProperties = Literal[
     "frameWorkerSettings",
 ]
 
-PropertyValue = Union[
-    str,
-    bool,
-    CameraInformation,
-    CameraType,
-    CameraActivitySettings,
-    list[DetectionZone],
-    list[CameraInput],
-    CameraFrameWorkerSettings,
-]
-
 
 # camera device
 ObjectClasses = Literal[
@@ -762,7 +751,6 @@ class MotionFrame(VideoFrame):
 
 
 SV = TypeVar("SV", bound=StateValue)
-PV = TypeVar("PV", bound=PropertyValue)
 
 
 class CameraStateChangedObject(Generic[SV], dict[str, SV]):
@@ -770,10 +758,10 @@ class CameraStateChangedObject(Generic[SV], dict[str, SV]):
     new_state: SV
 
 
-class CameraPropertyObservableObject(Generic[PV], dict[str, PV]):
+class CameraPropertyObservableObject(TypedDict):
     property: str
-    old_state: PV
-    new_state: PV
+    old_state: Any
+    new_state: Any
 
 
 class CameraDevice(Protocol):
@@ -821,7 +809,7 @@ class CameraDevice(Protocol):
     async def disconnect(self) -> None: ...
     async def reboot(self) -> None: ...
     async def snapshot(self, force_new: Optional[bool] = None) -> bytes: ...
-    async def get_frames(self) -> AsyncGenerator[VideoFrame, None]: ...
+    async def get_frames(self, prebuffer_duration: int = 0) -> AsyncGenerator[VideoFrame, None]: ...
     async def get_motion_frames(self) -> AsyncGenerator[MotionFrame, None]: ...
     async def get_ffmpeg_path(self) -> str: ...
     async def get_ice_servers(self) -> list[IceServer]: ...
@@ -923,9 +911,9 @@ class CameraDevice(Protocol):
         self, state_name: StateNames
     ) -> Observable[CameraStateChangedObject[StateValue]]: ...
 
-    def on_property_change(  # type: ignore
-        self, property_name: CameraPublicProperties
-    ) -> Observable[CameraPropertyObservableObject[PropertyValue]]: ...
+    def on_property_change(
+        self, property: Union[CameraPublicProperties, list[CameraPublicProperties]]
+    ) -> Observable[CameraPropertyObservableObject]: ...
 
     def remove_all_listeners(self) -> None: ...
 
@@ -972,9 +960,6 @@ CameraDeselectedCallback = Union[
 ]
 
 
-# abstract
-
-
 # DeviceManager
 DeviceManagerEventType = Literal[
     "cameraSelected",
